<?php

namespace LakeDrops\Drupal8ScaffoldDeveloper;

use Composer\Composer;
use Composer\IO\IOInterface;
use Composer\Script\Event;
use Composer\Script\ScriptEvents;
use DrupalComposer\DrupalScaffold\Handler as DrupalScaffoldHandler;
use LakeDrops\Component\Composer\BasePlugin;

/**
 * Composer plugin for handling drupal scaffold.
 */
class Plugin extends BasePlugin {

  /**
   * The scaffold handler object for events.
   *
   * @var \DrupalComposer\DrupalScaffold\Handler
   */
  protected $scaffoldHandler;

  /**
   * {@inheritdoc}
   */
  public function activate(Composer $composer, IOInterface $io) {
    parent::activate($composer, $io);
    $this->scaffoldHandler = new DrupalScaffoldHandler($composer, $io);
  }

  /**
   * {@inheritdoc}
   */
  public function getHandlerClass() {
    return Handler::class;
  }

  /**
   * {@inheritdoc}
   */
  public function getCapabilities(): array {
    return array(
      \Composer\Plugin\Capability\CommandProvider::class => CommandProvider::class,
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      ScriptEvents::POST_CREATE_PROJECT_CMD => 'prepareProject',
      ScriptEvents::POST_UPDATE_CMD => 'prepareProject',
    ];
  }

  /**
   * Post create and update project event callback.
   *
   * @param \Composer\Script\Event $event
   *   The event that triggered the plugin.
   *
   * @throws \Twig_Error_Loader
   * @throws \Twig_Error_Runtime
   * @throws \Twig_Error_Syntax
   */
  public function prepareProject(Event $event) {
    /** @var Handler $handler */
    $handler = $this->handler;
    $handler
      ->setEvent($event)
      ->setupLakeDropsProject();
  }

}
